@@ -17,13 +17,14 @@
 
 #include <math.h>
 #include <locale.h>
+#include <boost/algorithm/string.hpp>
 #include "sdf/Param.hh"
 
 using namespace sdf;
 
 class string_set : public boost::static_visitor<>
 {
-  public: string_set(const std::string &_value)
+  public: explicit string_set(const std::string &_value)
           {this->value = _value;}
 
   public: template <typename T>
@@ -36,7 +37,7 @@ class string_set : public boost::static_visitor<>
 
 class any_set : public boost::static_visitor<>
 {
-  public: any_set(const boost::any &_value)
+  public: explicit any_set(const boost::any &_value)
           {this->value = _value;}
 
   public: template <typename T>
@@ -385,7 +386,7 @@ bool Param::SetFromString(const std::string &_value)
 
   std::string tmp(str);
   std::string lowerTmp(str);
-  boost::to_lower(lowerTmp);
+  std::transform(lowerTmp.begin(), lowerTmp.end(), lowerTmp.begin(), ::tolower);
 
   // "true" and "false" doesn't work properly
   if (lowerTmp == "true")
@@ -397,40 +398,28 @@ bool Param::SetFromString(const std::string &_value)
 
   try
   {
-    // If the string is hex, try to use stoi and stoul, and then
-    // lexical cast as a last resort.
+    // Try to use stoi and stoul for integers, and
+    // stof and stod for floating point values.
+    // Use boost lexical cast as a last resort.
+    int numericBase = 10;
     if (isHex)
+        numericBase = 16;
+
+    if (this->dataPtr->typeName == "int")
+      this->dataPtr->value = std::stoi(tmp, NULL, numericBase);
+    else if (this->dataPtr->typeName == "unsigned int")
     {
-      if (this->dataPtr->typeName == "int")
-        this->dataPtr->value = std::stoi(tmp, NULL, 16);
-      else if (this->dataPtr->typeName == "unsigned int")
-      {
-        this->dataPtr->value = static_cast<unsigned int>(
-            std::stoul(tmp, NULL, 16));
-      }
-      else
-      {
-        boost::apply_visitor(string_set(tmp), this->dataPtr->value);
-      }
+      this->dataPtr->value = static_cast<unsigned int>(
+          std::stoul(tmp, NULL, numericBase));
     }
-    // Otherwise use stod, stof, and lexical cast
+    else if (this->dataPtr->typeName == "double")
+      this->dataPtr->value = std::stod(tmp);
+    else if (this->dataPtr->typeName == "float")
+      this->dataPtr->value = std::stof(tmp);
     else
-    {
-      if (this->dataPtr->typeName == "int")
-        this->dataPtr->value = std::stoi(tmp, NULL, 10);
-      else if (this->dataPtr->typeName == "unsigned int")
-      {
-        this->dataPtr->value = static_cast<unsigned int>(
-            std::stoul(tmp, NULL, 10));
-      }
-      else if (this->dataPtr->typeName == "double")
-        this->dataPtr->value = std::stod(tmp);
-      else if (this->dataPtr->typeName == "float")
-        this->dataPtr->value = std::stof(tmp);
-      else
-        boost::apply_visitor(string_set(tmp), this->dataPtr->value);
-    }
+      boost::apply_visitor(string_set(tmp), this->dataPtr->value);
   }
+
   // Catch invalid argument exception from std::stoi/stoul/stod/stof
   catch(std::invalid_argument &)
   {
